Utilities
*********

This section shows general objects and helper functions that are used with this package.


General Utilities
=================

.. autoclass:: balderhub.ant.lib.utils.PageMessageCollection
    :members:

.. autofunction:: balderhub.ant.lib.utils.filter_hrm_messages_by_toggle_bit_change

Pages
=====

.. autoclass:: balderhub.ant.lib.utils.pages.BaseAntplusPage
    :members:

.. autoclass:: balderhub.ant.lib.utils.pages.BaseReceivedAntplusPage
    :members:

Common
------

.. autoclass:: balderhub.ant.lib.utils.pages.common.Common70RequestDataPage
    :members:

.. autoclass:: balderhub.ant.lib.utils.pages.common.Common76ModeSettingsPage
    :members:

Heart-Rate-Monitor Profile Pages
--------------------------------


.. autoclass:: balderhub.ant.lib.utils.pages.hrm.BaseHrmPage
    :members:

.. autoclass:: balderhub.ant.lib.utils.pages.hrm.Hrm0DefaultDataPage
    :members:

.. autoclass:: balderhub.ant.lib.utils.pages.hrm.Hrm1CumulativeOperationTimePage
    :members:

.. autoclass:: balderhub.ant.lib.utils.pages.hrm.Hrm2ManufacturerInformationPage
    :members:

.. autoclass:: balderhub.ant.lib.utils.pages.hrm.Hrm3ProductInformationPage
    :members:

.. autoclass:: balderhub.ant.lib.utils.pages.hrm.Hrm4PreviousHeartBeatEventTimePage
    :members:

.. autoclass:: balderhub.ant.lib.utils.pages.hrm.Hrm5SwimIntervalSummaryPage
    :members:

.. autoclass:: balderhub.ant.lib.utils.pages.hrm.Hrm6CapabilitiesPage
    :members:

.. autoclass:: balderhub.ant.lib.utils.pages.hrm.Hrm7BatteryStatusPage
    :members:

.. autoclass:: balderhub.ant.lib.utils.pages.hrm.Hrm9DeviceInformationPage
    :members:

.. autoclass:: balderhub.ant.lib.utils.pages.hrm.Hrm32HrFeaturePage
    :members:

Extended Metadata
=================

.. autoclass:: balderhub.ant.lib.utils.extended_meta.BaseExtendedMetaFlagged
    :members:

.. autoclass:: balderhub.ant.lib.utils.extended_meta.BaseExtendedMetaLegacy
    :members:

.. autoclass:: balderhub.ant.lib.utils.extended_meta.ExtendedMetaFlaggedChannelId
    :members:

.. autoclass:: balderhub.ant.lib.utils.extended_meta.ExtendedMetaFlaggedRssi
    :members:

.. autoclass:: balderhub.ant.lib.utils.extended_meta.ExtendedMetaFlaggedTimestamp
    :members:

.. autoclass:: balderhub.ant.lib.utils.extended_meta.ExtendedMetaLegacyChannelId
    :members:
